@@ -12,7 +12,6 @@ from dateutil.parser import parse
 import os
 import numbers
 import requests
-import json
 
 
 def is_date(string, fuzzy=False):
@@ -22,23 +21,23 @@ def is_date(string, fuzzy=False):
     except ValueError:
         return False
 class Client:
-    def __init__ (config = {}):
+    def __init__ (self, config = {}):
         self.user  = config.get("user", False)
         self.password =  config.get("password", False)
-        if not user:
+        if not self.user:
             print ("Config is missing 'user'")
             sys.exit()
-        if not password:
+        if not self.password:
             print ("Config is missing 'password'")
             sys.exit()
         self.hashtag_list = config.get("hashtag_list","photos")
         self.current_hashtag = None
         self.path = os.path.abspath(os.path.dirname(__file__))
-        self.debug = settings.get("debug", False)
-        self.follow_profiles_list = follow_profiles_list
-        self.chromedriver_path = "/usr/lib/chromium-browser/chromedriver"
+        self.debug = config.get("debug", False)
+        self.follow_profiles_list = config.get("follow_profiles", None)
+        self.chromedriver_path = config.get(chromedriver_path, "/usr/lib/chromium-browser/chromedriver")
         self.likes_max = config.get("likes", 15)
-        self.watch_stories_minutes = config.get("watch_stories_min", 5)
+        self.watch_stories_minutes = config.get("watch_stories_minutes", 5)
         self.follows_max = config.get("follow", 0)
         self.unfollows_max = config.get("unfollow", 0)
         self.wait_between = config.get("wait_between_runs", 2)
@@ -89,7 +88,6 @@ class Client:
                 }
         }
         self.mobile = False
-        self.post_caption = settings.get("add_to_post_caption")
 
         if self.follow_profiles_list != None:
             self.followers_window_posY = [0]*len(self.follow_profiles_list)
